package com.pdaaphm.biz.service;

import java.util.List;
import java.util.Map;

import com.pdaaphm.biz.domain.AlgorithmIoField;
import com.pdaaphm.biz.dto.SubAlgorithmDTO;

/**
 * 算法输入输出字段Service接口
 *
 * @author xlk
 * @date 2023-07-26
 */
public interface IAlgorithmIoFieldService
{
    /**
     * 查询算法输入输出字段
     *
     * @param id 算法输入输出字段主键
     * @return 算法输入输出字段
     */
    public AlgorithmIoField selectAlgorithmIoFieldById(Long id);

    /**
     * 查询算法输入输出字段列表
     *
     * @param algorithmIoField 算法输入输出字段
     * @return 算法输入输出字段集合
     */
    public List<AlgorithmIoField> selectAlgorithmIoFieldList(AlgorithmIoField algorithmIoField);

    /**
     * 新增算法输入输出字段
     *
     * @param algorithmIoField 算法输入输出字段
     * @return 结果
     */
    public int insertAlgorithmIoField(AlgorithmIoField algorithmIoField);

    /**
     * 修改算法输入输出字段
     *
     * @param algorithmIoField 算法输入输出字段
     * @return 结果
     */
    public int updateAlgorithmIoField(AlgorithmIoField algorithmIoField);

    /**
     * 批量删除算法输入输出字段
     *
     * @param ids 需要删除的算法输入输出字段主键集合
     * @return 结果
     */
    public int deleteAlgorithmIoFieldByIds(Long[] ids);

    /**
     * 删除算法输入输出字段信息
     *
     * @param id 算法输入输出字段主键
     * @return 结果
     */
    public int deleteAlgorithmIoFieldById(Long id);

    List<SubAlgorithmDTO> getIoSubList(Long subTypeId, Long algoId);
}
